package com.example.tbadapter;

import android.content.Context;
import android.util.Log;

import com.open.ad.polyunion.listener.NativeAdsListener;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.AdRequestConfig;
import com.open.ad.polyunion.view.NativeAd;
import com.open.ad.polyunion.view.NativeAdsResponse;
import com.windmill.sdk.WMConstants;
import com.windmill.sdk.base.WMAdapterError;
import com.windmill.sdk.custom.WMCustomNativeAdapter;
import com.windmill.sdk.models.BidPrice;
import com.windmill.sdk.natives.WMNativeAdData;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

public class CloooudCustomNative extends WMCustomNativeAdapter {

    private boolean isReady = false;
    private List<WMNativeAdData> nativeAdDataList = new ArrayList<>();

    @Override
    public void loadAd(Context context, Map<String, Object> serverExtra, Map<String, Object> map1) {
        String codeId = (String) map1.get(WMConstants.PLACEMENT_ID);
        int[] screenSizeDP = Util.getScreenSizeInDP(context);
        AdRequestConfig requestConfig = new AdRequestConfig.Builder()
                .AdType(AdConfig.AD_TYPE_INTERSTITIAL)
                .slotId(codeId) //广告场景id
                .isVideoVoiceOn(false)//视频播放是否有声音
                .requestCount(1) //信息流广告请求条数
                .widthDp(screenSizeDP[0]) //请求图片宽度dp值
                .heightDp(0) //请求图片高度dp值
                /**
                 * 设置视频自动播放场景：
                 * ALWAYS - 所有网络环境均自动播放
                 * WIFI - WIFI网络环境自动播放
                 * NEVER - 所有网络环境均不会自动播放
                 */
                .videoAutoPlayPolicy(AdRequestConfig.VideoAutoPlayPolicy.ALWAYS) //                .addSougouAdTemplate(AdTemplate.BIG_IMG_TPL_ID)
                //                .addSougouAdTemplate(AdTemplate.DOWNLOAD_BIG_TPL_ID)
                .showDownloadConfirmDialog(true)
                .build();

        NativeAd nativeAds = new NativeAd(context, requestConfig);
        nativeAds.setListener(new NativeAdsListener() {
            @Override
            public void onAdReady(List<NativeAdsResponse> responses) {
                if (responses == null || responses.isEmpty()) {
                    callLoadFail(new WMAdapterError(9999, "没有返回数据"));
                    return;
                }
                isReady = true;
                nativeAdDataList.clear();
                for (NativeAdsResponse ad : responses) {
                    CloooudFeedNativeAD nativeAdLoader = new CloooudFeedNativeAD(CloooudCustomNative.this, ad);
                    if (isClientBidding()) {//bidding广告类型
                        double ecpm = ad.getPrice();//当无权限调用该接口时，SDK会返回错误码-1
                        if (ecpm < 0) {
                            ecpm = 0;
                        }
                        callLoadBiddingSuccess(new BidPrice(String.valueOf(ecpm))); //回传竞价广告价格
                    }
                    nativeAdDataList.add(nativeAdLoader);
                }
                callLoadSuccess(nativeAdDataList);
            }

            @Override
            public void onAdFailed(String msg) {
                Log.e("CLOOOUDAD", "NativeAd onAdFailed: $s");
                callLoadFail(new WMAdapterError(9999, msg));
            }
        });
    }

    public boolean isClientBidding() {
        return getBiddingType() == WMConstants.AD_TYPE_CLIENT_BIDING;
    }

    @Override
    public boolean isReady() {
        return isReady;
    }

    @Override
    public void destroyAd() {
        for (WMNativeAdData data:nativeAdDataList){
            CloooudFeedNativeAD nativeAD = (CloooudFeedNativeAD) data;
            nativeAD.destroy();
        }
    }

    @Override
    public List<WMNativeAdData> getNativeAdDataList() {
        return nativeAdDataList;
    }
}
