package com.example.tbadapter;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.open.ad.polyunion.bean.AdSource;
import com.open.ad.polyunion.bean.CAdInfo;
import com.open.ad.polyunion.listener.CAppDownloadListener;
import com.open.ad.polyunion.util.UIUtils;
import com.open.ad.polyunion.view.AdConfig;
import com.open.ad.polyunion.view.NativeAdsResponse;
import com.windmill.sdk.WMConstants;
import com.windmill.sdk.WindMillError;
import com.windmill.sdk.base.WMAdapterError;
import com.windmill.sdk.custom.WMCustomNativeAdapter;
import com.windmill.sdk.natives.WMImage;
import com.windmill.sdk.natives.WMNativeAdContainer;
import com.windmill.sdk.natives.WMNativeAdData;
import com.windmill.sdk.natives.WMNativeAdDataType;
import com.windmill.sdk.natives.WMNativeAdRender;

import java.util.List;

/**
 * @author zw
 * @date :2024/4/28 18:26
 * @projectName
 * @description:
 */
public class CloooudFeedNativeAD extends WMNativeAdData {

    private NativeAdsResponse response;
    private WMCustomNativeAdapter adAdapter;
    private WMNativeAdData wmNativeAdData = this;
    private DislikeInteractionCallback dislikeCallback;
    private boolean isAdReady = false;

    private Context context;

    public boolean isAdReady() {
        return isAdReady;
    }

    public CloooudFeedNativeAD(Context context,WMCustomNativeAdapter adAdapter, NativeAdsResponse response) {
        this.response = response;
        this.adAdapter = adAdapter;
        this.context = context;
    }

    /**
     * 根据类型设置video的监听，但是不生效针对头条
     *
     * @return
     */
    @Override
    public int getAdPatternType() {
        if (response == null) {
            return WMNativeAdDataType.NATIVE_UNKNOWN;
        }
        int type = response.getSelfRenderAdMediaType();
        switch (type) {
            case NativeAdsResponse.NATIVE_AD_STYLE_LARGE_IMAGE:
                return WMNativeAdDataType.NATIVE_BIG_IMAGE_AD;
            case NativeAdsResponse.NATIVE_AD_STYLE_SMALL_IMAGE:
                return WMNativeAdDataType.NATIVE_SMALL_IMAGE_AD;
            case NativeAdsResponse.NATIVE_AD_STYLE_GROUP_IMAGE:
                return WMNativeAdDataType.NATIVE_GROUP_IMAGE_AD;
            default:
                return WMNativeAdDataType.NATIVE_UNKNOWN;
        }
    }

    @Override
    public void setInteractionListener(final NativeAdInteractionListener adInteractionListener) {
        if (this.response != null) {
            response.setNativeActionListener(new NativeAdsResponse.NativeActionListener() {
                @Override
                public void onAdClick() {
                    if (adInteractionListener != null && adAdapter != null) {
                        adInteractionListener.onADClicked(adAdapter.getAdInFo());
                    }

                    if (adAdapter != null) {
                        adAdapter.callNativeAdClick(wmNativeAdData);
                    }
                }

                @Override
                public void onAdShow(CAdInfo cAdInfo) {
                    if (adInteractionListener != null && adAdapter != null) {
                        adInteractionListener.onADExposed(adAdapter.getAdInFo());
                    }

                    if (adAdapter != null) {
                        adAdapter.callNativeAdShow(wmNativeAdData);
                    }
                }

                @Override
                public void onError(String msg) {

                }

                @Override
                public void onAdClose(String dislikeReason) {
                    if (dislikeCallback == null) {
                        return;
                    }
                    if (!dislikeReason.isEmpty()) {
                        dislikeCallback.onSelected(0, dislikeReason, true);
                    }
                    dislikeCallback.onCancel();
                }

                @Override
                public void onExpressRenderFail(String msg) {
                    if (adInteractionListener != null && adAdapter != null) {
                        WindMillError adError = WindMillError.ERROR_AD_ADAPTER_PLAY;
                        adError.setMessage("code : 9999 , msg : " + msg);
                        adInteractionListener.onADError(adAdapter.getAdInFo(), adError);
                    }

                    if (adAdapter != null) {
                        adAdapter.callNativeAdShowError(wmNativeAdData, new WMAdapterError(9999, msg));
                    }
                }

                @Override
                public void onExpressRenderSuccess(View view, float width, float height) {
                    isAdReady = true;
                    if (!response.isExpressAd()) {
                        return;
                    }
                    if (adInteractionListener != null && adAdapter != null) {
                        adInteractionListener.onADRenderSuccess(adAdapter.getAdInFo(),response.getExpressAdView(), width, height);
                    }
                }

                @Override
                public void onExpressRenderTimeout() {
                    if (!response.isExpressAd()) {
                        return;
                    }
                    if (adInteractionListener != null && adAdapter != null) {
                        WindMillError adError = WindMillError.ERROR_LOAD_AD_TIME_OUT;
                        adInteractionListener.onADError(adAdapter.getAdInFo(), adError);
                    }

                    if (adAdapter != null) {
                        adAdapter.callNativeAdShowError(wmNativeAdData, new WMAdapterError(9999, "timeout"));
                    }
                }

                @Override
                public void onDislikeDialogShow() {
//                callDislikeShow();
                    if (dislikeCallback != null) {
                        dislikeCallback.onShow();
                    }
                }

                @Override
                public void onDownloadConfirmDialogDismissed() {

                }
            });
        }
    }

    /**
     * 根据类型设置下载的监听，针对头条生效
     *
     * @return
     */
    @Override
    public int getInteractionType() {
        if (response.getInteractionType() == AdConfig.NATIVE_INTERACTION_TYPE_DOWNLOAD) {
            return WMConstants.INTERACTION_TYPE_DOWNLOAD;
        }
        return WMConstants.INTERACTION_TYPE_BROWSER;

    }

    @Override
    public View getExpressAdView() {
        if (response != null) {
            View view = response.getExpressAdView();
            if (view != null) {
                RelativeLayout adContainer = new RelativeLayout(view.getContext());
                RelativeLayout.LayoutParams lpRoot = new RelativeLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT,
                        ViewGroup.LayoutParams.WRAP_CONTENT);
                adContainer.setLayoutParams(lpRoot);
                adContainer.addView(view);
                // 注册原生信息流广告可点击区域视图，建议为客户端单个原生广告位所有区域，在广告展现时调用
                response.registerNativeClickableView(adContainer, view.getContext(), adContainer, null);
                return adContainer;
            }else {
                RelativeLayout adContainer = new RelativeLayout(context);
                RelativeLayout.LayoutParams lpRoot = new RelativeLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT,
                        ViewGroup.LayoutParams.WRAP_CONTENT);
                adContainer.setLayoutParams(lpRoot);
                // 注册原生信息流广告可点击区域视图，建议为客户端单个原生广告位所有区域，在广告展现时调用
                response.registerNativeClickableView(adContainer, context, adContainer, null);
                return adContainer;
            }
        }
        return null;
    }

    /**
     * tt demo都是render之后才addView
     */
    @Override
    public void render() {
        if (response != null) {
            response.render();
        }
    }

    @Override
    public boolean isExpressAd() {
        return response.isExpressAd();
    }

    @Override
    public boolean isNativeDrawAd() {
        return false;
    }

    @Override
    public void setDislikeInteractionCallback(Activity activity, final DislikeInteractionCallback dislikeInteractionCallback) {
        //如果初始化ttAdManager.createAdNative(getApplicationContext())没有传入activity 则需要在此传activity，否则影响使用Dislike逻辑
        if (response == null) {
            return;
        }
        response.setTTDefaultDislikeDialog(activity);
        this.dislikeCallback = dislikeInteractionCallback;
    }

    @Override
    public void setDownloadListener(final AppDownloadListener appDownloadListener) {
        response.setAppDownloadListener(new CAppDownloadListener() {
            @Override
            public void onIdle() {
                appDownloadListener.onIdle();
            }

            @Override
            public void onProgressUpdate(int i) {
            }

            @Override
            public void onDownloadPaused() {
                appDownloadListener.onDownloadPaused(0, 0, "", "");
            }

            @Override
            public void onDownloadFinished() {
                appDownloadListener.onDownloadFinished(0, "", "");
            }

            @Override
            public void onDownloadFailed() {
                appDownloadListener.onDownloadFailed(0, 0, "", "");
            }

            @Override
            public void onInstalled() {
                appDownloadListener.onInstalled("", "");
            }
        });
    }


    @Override
    public int getNetworkId() {
        if (adAdapter != null) {
            return adAdapter.getChannelId();
        }
        return 0;
    }

    @Override
    public void destroy() {
        if (response != null) {
            response.onDestroy();
        }
    }

    @Override
    public void startVideo() {

    }

    @Override
    public void pauseVideo() {

    }

    @Override
    public void resumeVideo() {

    }

    @Override
    public void stopVideo() {

    }

    @Override
    public void bindMediaView(Context context, ViewGroup mediaLayout) {

    }

    @Override
    public void connectAdToView(Activity activity, WMNativeAdContainer adContainer, WMNativeAdRender adRender) {
        if (adRender != null) {
            //自渲染模式下 请在此处进行广告布局样式的绘制和数据的填充
            View view = getAdView(activity);
            if (adContainer != null) {
                adContainer.removeAllViews();
                if (view.getLayoutParams() == null) {
                    view.setLayoutParams(new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT));
                }
                adContainer.addView(view);
            }
        }
    }

    /**
     *  测试样例
     */
    private View getAdView(Context context) {
        FrameLayout frameLayout = new FrameLayout(context);
        frameLayout.setBackgroundColor(Color.parseColor("#330033"));
        TextView textView = new TextView(context);
        FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
        params.gravity = Gravity.CENTER;
        textView.setLayoutParams(params);
        textView.setTextColor(Color.parseColor("#FFFFFF"));
        textView.setText("请自行处理");
        frameLayout.addView(textView);
        frameLayout.setLayoutParams(new ViewGroup.LayoutParams(UIUtils.getScreenRealSizeInPx(context)[0], UIUtils.dp2px(context, 400)));
        return frameLayout;
    }

    @Override
    public void bindImageViews(Context context, List<ImageView> imageViews, int defaultImageRes) {
        //需要自己渲染Image
    }

    @Override
    public List<String> getImageUrlList() {
        return response.getImageUrls();
    }

    @Override
    public List<WMImage> getImageList() {
        return null;
    }

    @Override
    public void setAdLogoParams(FrameLayout.LayoutParams layoutParams) {

    }

    @Override
    public void bindViewForInteraction(Context context, View view, List<View> clickableViews, List<View> creativeViewList, View disLikeView) {
        if (this.response != null) {
            // 注册原生信息流广告可点击区域视图，建议为客户端单个原生广告位所有区域，在广告展现时调用
            response.registerNativeClickableView((ViewGroup) view, context, view, view);
        }
    }

    /**
     * 头条暂时没有这个监听
     *
     * @param nativeADMediaListener
     */
    @Override
    public void setMediaListener(WMNativeAdData.NativeADMediaListener nativeADMediaListener) {

    }

    @Override
    public String getCTAText() {
        return response.getCtaText();
    }

    @Override
    public String getTitle() {
        return response.getTitle();
    }

    @Override
    public String getDesc() {
        return response.getDesc();
    }

    @Override
    public Bitmap getAdLogo() {
        return null;
    }

    @Override
    public String getIconUrl() {
        return response.getLogoUrl();
    }

    @Override
    public View getAdChoice() {
        return null;
    }
}
